namerator
=========

generate random names from a list of like names

Installation
------------

From the project root directory::

    $ python setup.py install

Usage
-----

Simply run it::

    $ namerator

Use --help/-h to view info on the arguments::

    $ namerator --help
    usage: namerator [-h] [--num NUM] [--output OUTPUT]
                     [--freq-output FREQ_OUTPUT]
                     path

    positional arguments:
      path

    optional arguments:
      -h, --help            show this help message and exit
      --num NUM, -n NUM
      --output OUTPUT, -o OUTPUT
      --freq-output FREQ_OUTPUT, -f FREQ_OUTPUT


Release Notes
-------------

:0.1.0:
    Ready for release, works
:0.0.1:
    Project created
